@@ -10,7 +10,7 @@
 import functools
 
 from . import _combinators as pco
-from . import _location, _optable
+from . import _optable
 from . import _tla_combinators as intf
 from . import tokens
 from ._combinators import (
@@ -28,8 +28,6 @@ from ._combinators import (
     get,
     lookahead,
     optional,
-    or_,
-    question,
     return_,
     second,
     second_commit,
@@ -208,6 +206,8 @@ fixities = _generate_fixities()
 #     fun vs -> check S.empty vs
 #
 # let hint = locate anyident
+
+
 def hint():
     return intf.locate(intf.anyident())
 
@@ -309,6 +309,7 @@ def record_fields(is_start):
     assert not is_start, is_start
     # def f(sw, _, r):
     #     return tla_ast.Dot(r, sw)
+
     def f():
         return (
             attempt(intf.locate(intf.punct(".") << second >> intf.anyname()))
@@ -874,6 +875,7 @@ def complex_expr(b):
         #       fun ({core = (ds, e)} as letin) ->
         #         { letin with core =  Let (ds, e) }
         #     end;
+
         def f():
             return (
                 intf.locate(
